
0.7.0
-----

- adapted to new deltachat-0.7.1 bindings

- now reacting with showing the view type of a message content

- new "info" command to show database info

0.6.0
-----

- initial release with simple init and serve
